OC.L10N.register(
    "spreed",
    {
    "a conversation" : "keskustelu",
    "(Duration %s)" : "(Kesto %s)",
    "You attended a call with {user1}" : "Osallistuit puheluun käyttäjän {user1} kanssa",
    "_%n guest_::_%n guests_" : ["%n vieras","%n vierasta"],
    "You attended a call with {user1} and {user2}" : "Osallistuit puheluun käyttäjien {user1} ja {user2} kanssa",
    "You attended a call with {user1}, {user2} and {user3}" : "Osallistuit puheluun käyttäjien {user1}, {user2} ja {user3} kanssa",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3} ja {user4} kanssa",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Osallistuit puheluun käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kanssa",
    "_%n other_::_%n others_" : ["%n muu","%n muuta"],
    "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
    "Talk" : "Puhe",
    "Guest" : "Vieras",
    "The command does not exist" : "Komentoa ei ole olemassa",
    "Talk updates ✅" : "Talk-päivitykset ✅",
    "{actor} created the conversation" : "{actor} loi keskustelun",
    "You created the conversation" : "Sinä loit keskustelun",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sinä muutit keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
    "{actor} started a call" : "{actor} aloitti puhelun",
    "You started a call" : "Sinä aloitit puhelun",
    "{actor} joined the call" : "{actor} liittyi puheluun",
    "You joined the call" : "Sinä liityit puheluun",
    "{actor} left the call" : "{actor} poistui puhelusta",
    "You left the call" : "Sinä poistuit puhelusta",
    "{actor} unlocked the conversation" : "{actor} poisti keskustelun lukituksen",
    "You unlocked the conversation" : "Poistit keskustelun lukituksen",
    "{actor} locked the conversation" : "{actor} lukitsi keskustelun",
    "You locked the conversation" : "Sinä lukitsit keskustelun",
    "The conversation is now open to everyone" : "Keskustelu on nyt avoin kaikille",
    "{actor} opened the conversation to everyone" : "{actor} avasi keskustelun kaikille",
    "You opened the conversation to everyone" : "Avasit uuden keskustelun kaikille",
    "{actor} allowed guests" : "{actor} salli vieraat",
    "You allowed guests" : "Sinä sallit vieraat",
    "{actor} disallowed guests" : "{actor} esti vieraat",
    "You disallowed guests" : "Sinä estit vieraat",
    "{actor} set a password" : "{actor} asetti salasanan",
    "You set a password" : "Sinä asetit salasanan",
    "{actor} removed the password" : "{actor} poisti salasanan",
    "You removed the password" : "Sinä poistit salasanan",
    "{actor} added {user}" : "{actor} lisäsi käyttäjän {user}",
    "You joined the conversation" : "Liityit keskusteluun",
    "{actor} joined the conversation" : "{actor} liittyi keskusteluun",
    "You added {user}" : "Sinä lisäsit käyttäjän {user}",
    "{actor} added you" : "{actor} lisäsi sinut",
    "You left the conversation" : "Poistuit keskustelusta",
    "{actor} left the conversation" : "{actor} poistui keskustelusta",
    "{actor} removed {user}" : "{actor} poisti käyttäjän {user}",
    "You removed {user}" : "Sinä poistit käyttäjän {user}",
    "{actor} removed you" : "{actor} poisti sinut",
    "{actor} promoted {user} to moderator" : "{actor} nosti käyttäjän {user} moderaattoriksi",
    "You promoted {user} to moderator" : "Sinä nostit käyttäjän {user} moderaattoriksi",
    "{actor} promoted you to moderator" : "{actor} nosti sinut moderaattoriksi",
    "{actor} demoted {user} from moderator" : "{actor} poisti moderaattorin oikeudet käyttäjältä {user}",
    "You demoted {user} from moderator" : "Sinä poistit moderaattorin oikeudet käyttäjältä {user}",
    "{actor} demoted you from moderator" : "{actor} poisti sinulta moderaattorin oikeudet",
    "{actor} shared a file which is no longer available" : "{actor} jakoi kanssasi tiedoston, joka ei ole enää saatavilla",
    "You shared a file which is no longer available" : "Jaoit tiedoston, joka ei ole enää saatavilla",
    "%s (guest)" : "%s (vieras)",
    "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
    "Call with {user1} and {user2} (Duration {duration})" : "Puhelu käyttäjien {user1} ja {user2} kesken (Kesto {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
    "Write to conversation" : "Kirjoita keskusteluun",
    "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
    "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
    "Conversation invitation" : "Keskustelukutsu",
    "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
    "Join »%s«" : "Liity »%s«",
    "Password request: %s" : "Salasanapyyntö: %s",
    "Private conversation" : "Yksityinen keskustelu",
    "Deleted user (%s)" : "Poistettiin käyttäjä (%s)",
    "{user} sent you a private message" : "{user} lähetti sinulle yksityisviestin",
    "{user} sent a message in conversation {call}" : "{user} lähetti viestin keskusteluun {call}",
    "A deleted user sent a message in conversation {call}" : "Poistettu käyttäjä lähetti viestin keskusteluun {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (vieras) lähetti viestin keskusteluun {call}",
    "A guest sent a message in conversation {call}" : "Vieras lähetti viestin keskusteluun {call}",
    "{user} replied to your private message" : "{user} vastasi yksityisviestiisi",
    "{user} replied to your message in conversation {call}" : "{user} vastasi viestiisi keskustelussa {call}",
    "A guest replied to your message in conversation {call}" : "Vieras vastasi viestiisi keskustelussa {call}",
    "{user} mentioned you in a private conversation" : "{user} mainitsi sinut yksityiskeskustelussa",
    "{user} mentioned you in conversation {call}" : "{user} mainitsi sinut keskustelussa {call}",
    "A deleted user mentioned you in conversation {call}" : "Poistettu käyttäjä mainitsi sinut keskustelussa {call}",
    "A guest mentioned you in conversation {call}" : "Vieras mainitsi sinut keskustelussa {call}",
    "View chat" : "Näytä keskustelu",
    "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
    "Join call" : "Liity puheluun",
    "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
    "Answer call" : "Vastaa puheluun",
    "Call back" : "Soita takaisin",
    "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
    "Open settings" : "Avaa asetukset",
    "Conversations" : "Keskustelut",
    "Messages" : "Viestit",
    "{user}" : "{user}",
    "Messages in {conversation}" : "Viestit keskustelussa {conversation}",
    "{user} in {conversation}" : "{user} keskustelussa {conversation}",
    "Something unexpected happened." : "Jotain odottamatonta tapahtui.",
    "The email address is invalid." : "Sähköpostiosoite on virheellinen.",
    "The language is invalid." : "Kieli on virheellinen.",
    "The country is invalid." : "Maa on virheellinen.",
    "Something unexpected happened. Please try again later." : "Jotain odottamatonta tapahtui. Yritä myöhemmin uudelleen.",
    "Austria" : "Itävalta",
    "Belgium" : "Belgia",
    "Bulgaria" : "Bulgaria",
    "Brazil" : "Brasilia",
    "Canada" : "Kanada",
    "Switzerland" : "Sveitsi",
    "Chile" : "Chile",
    "China" : "Kiina",
    "Cuba" : "Kuuba",
    "Cyprus" : "Kypros",
    "Germany" : "Saksa",
    "Denmark" : "Tanska",
    "Estonia" : "Viro",
    "Egypt" : "Egypti",
    "Spain" : "Espanja",
    "Finland" : "Suomi",
    "France" : "Ranska",
    "Greece" : "Kreikka",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Unkari",
    "Ireland" : "Irlanti",
    "India" : "Intia",
    "Iraq" : "Irak",
    "Iceland" : "Islanti",
    "Italy" : "Italia",
    "Japan" : "Japani",
    "Kenya" : "Kenia",
    "Lithuania" : "Liettua",
    "Latvia" : "Latvia",
    "Montenegro" : "Montenegro",
    "Norway" : "Norja",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Poland" : "Puola",
    "Portugal" : "Portugali",
    "Romania" : "Romania",
    "Sweden" : "Ruotsi",
    "Singapore" : "Singapore",
    "Slovakia" : "Slovakia",
    "Somalia" : "Somalia",
    "Thailand" : "Thaimaa",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkki",
    "Ukraine" : "Ukraina",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
    "Conversation not found" : "Keskustelua ei löydy",
    "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
    "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
    "Leave call" : "Poistu puhelusta",
    "Stay in call" : "Pysy puhelussa",
    "Discuss this file" : "Keskustele tästä tiedostosta",
    "Share this file with others to discuss it" : "Jaa tämä tiedosto muiden kanssa keskustellaksesi siitä",
    "Share this file" : "Jaa tämä tiedosto",
    "Join conversation" : "Liity keskusteluun",
    "Request password" : "Pyydä salasana",
    "Error requesting the password." : "Virhe pyytäessä salasanaa.",
    "This conversation has ended" : "Tämä keskustelu on päättynyt",
    "Limit to groups" : "Rajoita ryhmiin",
    "Guests can still join public conversations." : "Vieraat voivat silti liittyä julkisiin keskusteluihin.",
    "Everyone" : "Kaikki",
    "Save changes" : "Tallenna muutokset",
    "Saving …" : "Tallennetaan…",
    "Saved!" : "Tallennettu!",
    "None" : "Ei mitään",
    "User" : "Käyttäjä",
    "Disabled" : "Pois käytöstä",
    "Moderators" : "Moderaattorit",
    "Users" : "Käyttäjät",
    "Commands" : "Komennot",
    "Beta" : "Beta",
    "Name" : "Nimi",
    "Command" : "Komento",
    "General settings" : "Yleiset asetukset",
    "Default notification settings" : "Ilmoitusten oletusasetukset",
    "Default group notification" : "Ryhmän oletusilmoitus",
    "Integration into other apps" : "Integraatio muihin sovelluksiin",
    "Allow conversations on files" : "Salli keskustelut tiedostoista",
    "All messages" : "Kaikki viestit",
    "@-mentions only" : "Vain @-maininnat",
    "Off" : "Pois",
    "Language" : "Kieli",
    "Country" : "Maa",
    "Status" : "Tila",
    "Created at" : "Luotu",
    "Pending" : "Odottaa",
    "Error" : "Virhe",
    "Blocked" : "Estetty",
    "Active" : "Aktiivinen",
    "Expired" : "Vanhentunut",
    "The account could not be deleted. Please try again later." : "Tätä tiliä ei voitu poistaa. Yritä myöhemmin uudelleen.",
    "_%n user_::_%n users_" : ["%n käyttäjä","%n käyttäjää"],
    "Matterbridge integration" : "Matterbridge-integraatio",
    "Enable Matterbridge integration" : "Käytä Matterbridge-integraatiota",
    "Downloading …" : "Ladataan…",
    "Installed version: {version}" : "Asennettu versio: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binääriä ei löytynyt tai sitä ei voitu suorittaa.",
    "Failed to execute Matterbridge binary." : "Matterbridge-binäärin suorittaminen epäonnistui.",
    "Shared secret" : "Jaettu salaisuus",
    "Validate SSL certificate" : "Vahvista SSL-varmenne",
    "Delete this server" : "Poista tämä palvelin",
    "Status: Checking connection" : "Tila: Tarkistetaan yhteyttä",
    "OK: Running version: {version}" : "OK: Suoritetaan versiota: {version}",
    "Error: Unknown error occurred" : "Virhe: Tuntematon virhe",
    "Saved" : "Tallennettu",
    "Add a new server" : "Lisää uusi palvelin",
    "STUN server URL" : "STUN-palvelimen osoite",
    "STUN servers" : "STUN-palvelimet",
    "TURN server URL" : "TURN-palvelimen osoite",
    "TURN server protocols" : "TURN-palvelimen protokollat",
    "Test this server" : "Testaa tämä palvelin",
    "TURN servers" : "TURN-palvelin",
    "Copy link" : "Kopioi linkki",
    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
    "Conversation link copied to clipboard." : "Keskustelulinkki kopioitu leikepöydälle.",
    "The link could not be copied." : "Linkkiä ei voitu kopioida.",
    "Show your screen" : "Näytä oma näyttösi",
    "Stop screensharing" : "Lopeta näytön jakaminen",
    "Settings" : "Asetukset",
    "Dismiss" : "Hylkää",
    "No audio" : "Ei ääntä",
    "Mute audio" : "Mykistä ääni",
    "No camera" : "Ei kameraa",
    "Disable video" : "Poista video käytöstä",
    "Enable video" : "Käytä videota",
    "Screensharing options" : "Näytönjakamisen valinnat",
    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
    "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
    "Back" : "Takaisin",
    "You" : "Sinä",
    "Show screen" : "Näytä näyttö",
    "Mute" : "Mykistä",
    "Stop following" : "Lopeta seuraaminen",
    "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
    "Call in progress" : "Puhelu meneillään",
    "Favorite" : "Suosikki",
    "Conversation settings" : "Keskustelun asetukset",
    "Chat notifications" : "Keskusteluilmoitukset",
    "Leave conversation" : "Poistu keskustelusta",
    "Delete conversation" : "Poista keskustelu",
    "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
    "Password protection" : "Salasanasuojaus",
    "Enter a password" : "Syötä salasana",
    "Copy conversation link" : "Kopioi keskustelulinkki",
    "Enable lobby" : "Käytä aulaa",
    "Start time (optional)" : "Aloitusaika (valinnainen)",
    "Save" : "Tallenna",
    "Edit" : "Muokkaa",
    "Nextcloud user" : "Nextcloud-käyttäjä",
    "Matrix channel" : "Matrix-kanava",
    "Mattermost user" : "Mattermost-käyttäjä",
    "Channel name" : "Kanavan nimi",
    "Password" : "Salasana",
    "Rocket.Chat channel" : "Rocket.Chat-kanava",
    "Skip TLS verification" : "Ohita TLS-vahvistus",
    "API token" : "API-poletti",
    "Login" : "Kirjaudu",
    "Nickname" : "Nimimerkki",
    "Connection password" : "Yhteyden salasana",
    "IRC channel" : "IRC-kanava",
    "NickServ nickname" : "NickServ-nimimerkki",
    "NickServ password" : "NickServ-salasana",
    "Use TLS" : "Käytä TLS:ää",
    "Use SASL" : "Käytä SASL:ia",
    "Client ID" : "Asiakkaan tunniste",
    "Bridge saved" : "Silta tallennettu",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "You: {lastMessage}" : "Sinä: {lastMessage}",
    "No matches" : "Ei täsmääviä",
    "Loading" : "Ladataan",
    "No search results" : "Ei hakutuloksia",
    "Groups" : "Ryhmät",
    "Circles" : "Piirit",
    "Users, groups and circles" : "Käyttäjät, ryhmät ja piirit",
    "Users and groups" : "Käyttäjät ja ryhmät",
    "Users and circles" : "Käyttäjät ja piirit",
    "Groups and circles" : "Ryhmät ja piirit",
    "Other sources" : "Muut lähteet",
    "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
    "Creating your conversation" : "Luodaan keskustelua",
    "Error while creating the conversation" : "Virhe keskustelua luotaessa",
    "Link copied to the clipboard!" : "Linkki kopioitu leikepöydälle!",
    "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
    "Password protect" : "Suojaa salasanalla",
    "Add participants" : "Lisää osallistujat",
    "Create conversation" : "Luo keskustelu",
    "Close" : "Sulje",
    "Choose a password" : "Valitse salasana",
    "Search participants" : "Etsi osallistujia",
    "Conversation name" : "Keskustelun nimi",
    "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
    "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
    "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
    "Microphone" : "Mikrofoni",
    "Camera" : "Kamera",
    "No microphone available" : "Ei mikrofonia saatavilla",
    "Select microphone" : "Valitse mikrofoni",
    "No camera available" : "Ei kameraa saatavilla",
    "Select camera" : "Valitse kamera",
    "Reply" : "Vastaa",
    "Go to file" : "Siirry tiedostoon",
    "Scroll to bottom" : "Vieritä alas",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "Share files to the conversation" : "Jaa tiedostoja keskusteluun",
    "Upload new files" : "Lähetä uusia tiedostoja",
    "Add emoji" : "Lisää emoji",
    "Send message" : "Lähetä viesti",
    "File to share" : "Jaettava tiedosto",
    "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
    "Invalid path selected" : "Valittu virheellinen polku",
    "moderator" : "moderaattori",
    "guest" : "vieras",
    "Demote from moderator" : "Alenna moderaattorista",
    "Promote to moderator" : "Ylennä moderaattoriksi",
    "Remove participant" : "Poista osallistuja",
    "Add users" : "Lisää käyttäjiä",
    "Add groups" : "Lisää ryhmiä",
    "Add emails" : "Lisää sähköpostiosoitteita",
    "Add circles" : "Lisää piirejä",
    "Searching …" : "Haetaan…",
    "No results" : "Ei tuloksia",
    "Add users, groups or circles" : "Lisää käyttäjiä, ryhmiä tai piirejä",
    "Add users or groups" : "Lisää käyttäjiä tai ryhmiä",
    "Add users or circles" : "Lisää käyttäjiä tai piirejä",
    "Add groups or circles" : "Lisää ryhmiä tai piirejä",
    "Add other sources" : "Lisää muita lähteitä",
    "Participants" : "Osallistujat",
    "Chat" : "Keskustelu",
    "Display name: " : "Näyttönimi:",
    "Choose devices" : "Valitse laitteet",
    "Attachments folder" : "Liitteiden kansio",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Focus the chat input" : "Kohdista keskustelun syötteeseen",
    "Search" : "Etsi",
    "Select location for attachments" : "Valitse sijainti liitteille",
    "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
    "Start call" : "Aloita puhelu",
    "Toggle fullscreen" : "Koko näyttö päälle/pois",
    "Rename conversation" : "Nimeä keskustelu uudelleen",
    "Mute others" : "Mykistä muut",
    "Grid view" : "Ruudukkonäkymä",
    "Send" : "Lähetä",
    "Add more files" : "Lisää enemmän tiedostoja",
    "No unread mentions" : "Ei lukemattomia mainintoja",
    "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
    "Start a conversation" : "Aloita keskustelu",
    "You were mentioned" : "Sinut mainittiin",
    "Message without mention" : "Viesti ilman mainintaa",
    "Mention room" : "Mainitse huone",
    "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
    "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
    "Select conversation" : "Valitse keskustelu",
    "Link to a conversation" : "Linkki keskusteluun",
    "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
    "Do not disturb" : "Älä häiritse",
    "Away" : "Poissa",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "Join here" : "Liity tähän",
    "Leave this page" : "Poistu tältä sivulta",
    "Default" : "Oletus",
    "Microphone {number}" : "Mikrofoni {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Kaiutin {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vaikuttaa siltä, että puhut vaikka sinut on mykistetty. Poista mykistys, jotta muut kuulevat sinut",
    "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
    "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
    "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
    "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
    "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
    "This conversation is password-protected" : "Tämä keskustelu on salasanasuojattu",
    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
    "TURN server" : "TURN-palvelin",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
    "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
    "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "New in Talk 6" : "Uutta Talkin 6-versiossa",
    "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
    "E-mail of the user" : "Käyttäjän sähköpostiosoite",
    "Error: Can not connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
    "UDP and TCP" : "UDP ja TCP",
    "UDP only" : "Vain UDP",
    "TCP only" : "Vain TCP",
    "Share whole screen" : "Jaa koko näyttö",
    "Share a single window" : "Jaa yksittäinen ikkuna",
    "Mute audio (m)" : "Mykistä äänet (m)",
    "Unmute audio (m)" : "Palauta äänet (m)",
    "Disable video (v)" : "Poista video käytöstä (v)",
    "Enable video (v)" : "Ota video käyttöön (v)",
    "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
    "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
    "Remove" : "Poista",
    "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
    "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
    "Enabled" : "Käytössä",
    "Show matterbridge log" : "Näytä matterbridge-loki",
    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
    "Share link" : "Jaa linkki",
    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
    "Fullscreen (f)" : "Koko näytön tila (f)",
    "Error while uploading file" : "Virhe tiedostoa lähettäessä"
},
"nplurals=2; plural=(n != 1);");
